==> ZenTaoPMS.17.2.php8.0.zip: zentaopms/extension/max/user/ext/model/class/bizext.class.php <==
<?php //0067d
if(!extension_loaded('ionCube Loader')){$__oc=strtolower(substr(php_uname(),0,3));$__ln='ioncube_loader_'.$__oc.'_'.substr(phpversion(),0,3).(($__oc=='win')?'.dll':'.so');if(function_exists('dl')){@dl($__ln);}if(function_exists('_il_exec')){return _il_exec();}$__ln='/ioncube/'.$__ln;$__oid=$__id=realpath(ini_get('extension_dir'));$__here=dirname(__FILE__);if(strlen($__id)>1&&$__id[1]==':'){$__id=str_replace('\\','/',substr($__id,2));$__here=str_replace('\\','/',substr($__here,2));}$__rd=str_repeat('/..',substr_count($__id,'/')).$__here.'/';$__i=strlen($__rd);while($__i--){if($__rd[$__i]=='/'){$__lp=substr($__rd,0,$__i).$__ln;if(file_exists($__oid.$__lp)){$__ln=$__lp;break;}}}if(function_exists('dl')){@dl($__ln);}}else{die('The file '.__FILE__." is corrupted.\n");}if(function_exists('_il_exec')){return _il_exec();}
$documentRoot = isset($_SERVER['SCRIPT_FILENAME']) ? dirname($_SERVER['SCRIPT_FILENAME']) : $_SERVER['DOCUMENT_ROOT'];
$link = is_file($documentRoot . '/loader-wizard.php') ? '/loader-wizard.php' : 'http://www.ioncube.com/lw/';
echo "<html>
  <head>
    <meta http-equiv='content-type' content='text/html; charset=utf-8' />
    <title>error</title>
  </head>
  <body>
    <h2 style='color:red;text-align:center'>未安装 ioncube loader</h2>
    <p>您需要安装ioncube loader才能使用该功能， 使用<a href='$link'>ioncube loader安装向导</a>。</p>
    <br /><br /><br />
    <h2 style='color:red;text-align:center'>Ioncube loader doesn't installed.</h2>
    <p>You haven't installed ioncube loader extension, please visit <a href='$link'>the install wizard</a> to install it.</p>
  </body>
</html>";
exit;

?>
HR+cPqGsfBmQ7nspLu8ndoFjP3DAdXU629zwij9YMNNcDvpKt3PO9b9WMjmPLPIUuReZTazqynYu
34313goVSe2N8CHzqzcWXQuta56pUzuC2LOV0qIR3XQcJKdgk9Runu/vcEEih6MCdAPRLem0G8K9
XA2nvDlSWhZ/rg9gckklgIV+XwSmiTfTBkZaZnioXpB2OQrwK6EozgZ23QC0zV5hUMrPFLFZxZbJ
2uQ9wYD16wZTAwgCp/5MbiqxPx5FJMh7RZbTlpZcXD1pd4J6zl+W2So0SuRDnEYJ6Fcan9PfjqZp
BNQXusW6oQyl/KDp8ba6RVYBeZdYJCX3NqtFBCg6jAdwW8d8jcoGXFsSBi8fuymlWS27JGI/hSWu
Co4Qo4dkjYVOIlNnCp8ecCHbXuiYPvRloz1ONLdQ2nsoji2Qev43reQZDY3t53IHwKaSLJJDDTow
1eJ7Feil8GwgKLKF+2AG1n0F2ybsru7LErLs83MV98IsI4gBU827yVq8slaOoHh+7ATMvvRjKLPS
jejpDY/RpTc25ETUAVaKuR3xNnGlf4X2NGLlKB/Oiew1rtxFaAOsk3xMXIVV6tj1xZ7FeOQ/cur3
NUSE7TuS+LoVvyRSapwfIUV8Yvyg8qa08noTIQVhE9AxGhbOUvhubJdWOrSas/WGKUY8C5DlXI4E
GfHnH4H7xuJ991j7FJdlSe0dfeK8ymYtOOOv+oom2AFYnqjaUBJ3Ru4Q

==> ZenTaoPMS.17.4.php7.0.zip: zentaopms/extension/max/user/ext/model/class/bizext.class.php <==
<?php //0067d
if(!extension_loaded('ionCube Loader')){$__oc=strtolower(substr(php_uname(),0,3));$__ln='ioncube_loader_'.$__oc.'_'.substr(phpversion(),0,3).(($__oc=='win')?'.dll':'.so');if(function_exists('dl')){@dl($__ln);}if(function_exists('_il_exec')){return _il_exec();}$__ln='/ioncube/'.$__ln;$__oid=$__id=realpath(ini_get('extension_dir'));$__here=dirname(__FILE__);if(strlen($__id)>1&&$__id[1]==':'){$__id=str_replace('\\','/',substr($__id,2));$__here=str_replace('\\','/',substr($__here,2));}$__rd=str_repeat('/..',substr_count($__id,'/')).$__here.'/';$__i=strlen($__rd);while($__i--){if($__rd[$__i]=='/'){$__lp=substr($__rd,0,$__i).$__ln;if(file_exists($__oid.$__lp)){$__ln=$__lp;break;}}}if(function_exists('dl')){@dl($__ln);}}else{die('The file '.__FILE__." is corrupted.\n");}if(function_exists('_il_exec')){return _il_exec();}
$documentRoot = isset($_SERVER['SCRIPT_FILENAME']) ? dirname($_SERVER['SCRIPT_FILENAME']) : $_SERVER['DOCUMENT_ROOT'];
$link = is_file($documentRoot . '/loader-wizard.php') ? '/loader-wizard.php' : 'http://www.ioncube.com/lw/';
echo "<html>
  <head>
    <meta http-equiv='content-type' content='text/html; charset=utf-8' />
    <title>error</title>
  </head>
  <body>
    <h2 style='color:red;text-align:center'>未安装 ioncube loader</h2>
    <p>您需要安装ioncube loader才能使用该功能， 使用<a href='$link'>ioncube loader安装向导</a>。</p>
    <br /><br /><br />
    <h2 style='color:red;text-align:center'>Ioncube loader doesn't installed.</h2>
    <p>You haven't installed ioncube loader extension, please visit <a href='$link'>the install wizard</a> to install it.</p>
  </body>
</html>";
exit;

?>
HR+cPsjA4XG5a+PRPFw7Dtu9QSMnv6dHICJRWy6fdS/9fT0aYm3WWYMoP2WUosmLxjrXDOzAgfGw
R9WGOyNw2JxmZDl3W39yVF+KgJU0gmKr9jIcSGLnjVp6pVVIBZQilm9hHMTioOH9yJq1fSrO+RPo
eLAvgPTU+NDAjkhTV27sr9wYCX2JD86ut1fiJEgDLKFjl+7E6UrUmoxSt6iEBZMssTfdHnzzC2mf
1ldWVjMfeeEXGgLmykKGeGxnsdWmRzklVe0p2ffYZmmKiV4x1jyAOCj8u5/pvyctsdvh/BhfwiMp
veFKfP50sKBCpvdVpwIXShTf4tnzvLf7u+3Mgg6wiFPdRMZyJg42sqYWYdfhHR4e0VSxcNtmM06H
HMzmA/8oDGg6C+abtBvFdFTFj4tasFq2TtZUw8fF842C/mmXmsJtWhXnvhA6yDl22yxgc7xKFRnh
unY/J3UvG6ZfVv3uf0sZJprfgQdEqIf5oKxEDhWks4FxYE6QAMNmW6PoACsiGiEvE8jZ8VXG7M0j
KzedVweq/2loT9kILgATkWllOMrKr+rsi/oIInf6iSLRpDMs3vp2cxO+RW67CcLqbA2CeD7n+Tjt
1SIlleXCrT34fAX10aqdKNKCR7/lqVbpL0eXcP2EMRZ4B/DvuEVk2CObjvfFGJEJu/86HaOu2bsI
A3+Ox4bL0QkK4O1YUXm+1eBDypzFIp9KTVkZqc5MWsnTICbqIxc5566iU7d1D0==
